@@ -3,17 +3,14 @@ package CatalystX::CRUD::YUI;
 use warnings;
 use strict;
 use Carp;
-use CatalystX::CRUD::YUI::LiveGrid;
+use CatalystX::CRUD::YUI::DataTable;
 use CatalystX::CRUD::YUI::Serializer;
 use base qw( Class::Accessor::Fast );
-use MRO::Compat;
-use mro "c3";
-use Data::Dump qw( dump );
+use Class::C3;
 
-__PACKAGE__->mk_accessors(
-    qw( serializer_class livegrid_class ));
+__PACKAGE__->mk_accessors(qw( datatable_class serializer_class ));
 
-our $VERSION = '0.030_01';
+our $VERSION = '0.001';
 
 =head1 NAME
 
@@ -21,29 +18,11 @@ CatalystX::CRUD::YUI - YUI for your CatalystX::CRUD view
 
 =head1 SYNOPSIS
 
- package MyApp::Controller::Foo;
- use strict;
- use base qw(
-    CatalystX::CRUD::YUI::Controller
-    CatalystX::CRUD::Controller::RHTMLO
- );
- 
- # config here -- see CatalystX::CRUD::Controller docs
- 
- 1;
+ # TODO
 
 =head1 DESCRIPTION
 
-CatalystX::CRUD::YUI is a crud application using the Yahoo
-User Interface and ExtJS toolkits, and CatalystX::CRUD components. It is
-derived largely from the Rose::DBx::Garden::Catalyst project
-but now with support for DBIx::Class via the 
-CatalystX::CRUD::ModelAdapter::DBIC package.
-
-The t/ test directly for this package contains two full
-Catalyst applications, one for RDBO and one for DBIC, both
-using the same basic db schema. Looking at those examples 
-is a good way to start.
+ # TODO
  
 =head1 METHODS
 
@@ -57,15 +36,15 @@ Only new or overridden method are documented here.
 
 sub new {
     my $self = shift->next::method(@_);
+    $self->{datatable_class}  ||= 'CatalystX::CRUD::YUI::DataTable';
     $self->{serializer_class} ||= 'CatalystX::CRUD::YUI::Serializer';
-    $self->{livegrid_class}   ||= 'CatalystX::CRUD::YUI::LiveGrid';
     return $self;
 }
 
-=head2 livegrid( I<opts> )
+=head2 datatable( I<opts> )
 
-Returns a CatalystX::CRUD::YUI::LiveGrid object
-ready for the livegrid_*.tt templates.
+Returns a CatalystX::CRUD::YUI::DataTable object
+ready for the yui_datatable.tt template.
 
 I<opts> should consist of:
 
@@ -114,9 +93,10 @@ sub _fix_args {
     return @arg;
 }
 
-sub livegrid {
+sub datatable {
     my $self = shift;
-    return $self->livegrid_class->new( _fix_args(@_), yui => $self );
+    #carp "get datatable";
+    return $self->datatable_class->new( _fix_args(@_), yui => $self );
 }
 
 =head2 serializer
@@ -153,6 +133,7 @@ sponsored the development of this software.
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 by the Regents of the University of Minnesota.
+All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
