@@ -4,14 +4,13 @@ use warnings;
 use base qw( CatalystX::CRUD::View::Excel );
 use Carp;
 use Data::Dump qw( dump );
-use MRO::Compat;
-use mro "c3";
+use Class::C3;
 use Path::Class;
 use Class::Inspector;
 use CatalystX::CRUD::YUI;
 use CatalystX::CRUD::YUI::TT;
 
-our $VERSION = '0.030_01';
+our $VERSION = '0.001';
 
 =head1 NAME
 
@@ -35,7 +34,7 @@ The default config here is:
 
 # default config here instead of new() so subclasses can more easily override.
 __PACKAGE__->config( TEMPLATE_EXTENSION => '.tt' );
-$Template::Directive::WHILE_MAX = 65000;
+$Template::Directive::WHILE_MAX = 64000;
 
 =head1 METHODS
 
@@ -80,15 +79,6 @@ sub new {
     return $self;
 }
 
-=head2 get_template_filename
-
-Always returns C<crud/list.xls.tt> rather than depending on current
-Action path.
-
-=cut
-
-sub get_template_filename {'crud/list.xls.tt'}
-
 =head2 get_template_params
 
 Overrides base method to add some other default variables.
@@ -136,7 +126,7 @@ sponsored the development of this software.
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 by the Regents of the University of Minnesota.
-
+All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
