@@ -4,25 +4,14 @@ use warnings;
 use strict;
 use Carp;
 use base 'Class::Accessor::Fast';
-use MRO::Compat;
-use mro "c3";
+use Class::C3;
 use Scalar::Util qw( blessed );
 use JSON::XS ();
 use Data::Dump qw( dump );
 
-__PACKAGE__->mk_accessors(qw( datetime_format yui html_escape ));
+__PACKAGE__->mk_accessors(qw( datetime_format yui ));
 
-our $VERSION = '0.030_01';
-
-# html escaping
-my %Ents = (
-    '>' => '&gt;',
-    '<' => '&lt;',
-    '&' => '&amp;',
-    '"' => '&quot;',
-    "'" => '&apos;'
-);
-my $ToEscape = join( '', keys %Ents );
+our $VERSION = '0.001';
 
 =head1 NAME
 
@@ -30,25 +19,11 @@ CatalystX::CRUD::YUI::Serializer - flatten CatalystX::CRUD::Object instances
 
 =head1 SYNOPSIS
 
- use CatalystX::CRUD::YUI::Serializer;
- 
- my $serializer = CatalystX::CRUD::YUI::Serializer->new(
-                    datetime_format => '%Y-%m-%d %H:%M:%S',
-                    html_escape     => 1,
-                    );
-                    
- my $hashref = $serializer->serialize_object( 
-                    object      => $my_object,
-                    col_names   => [qw( id name email )],  
-                    cat_context => $c,
-                    rel_info    => $rel_info,
-                );
- 
+ # TODO
 
 =head1 DESCRIPTION
 
-CatalystX::CRUD::YUI::Serializer turns objects into hashrefs,
-typically for rendering as JSON.
+ # TODO
  
 =head1 METHODS
 
@@ -66,7 +41,6 @@ sub new {
     my $class = shift;
     my $self = $class->next::method( ref $_[0] ? @_ : {@_} );
     $self->{datetime_format} ||= '%Y-%m-%d %H:%M:%S';
-    $self->{html_escape} = 1 unless defined $self->{html_escape};
     return $self;
 }
 
@@ -77,13 +51,6 @@ Used in serialize_object().
 
 =cut
 
-=head2 html_escape
-
-serialize_object() will escape all special HTML characters by default.
-Set html_escape to false (0) if turn that feature off.
-
-=cut
-
 =head2 serialize_object( I<params> )
 
 Serialize a CatalystX::CRUD::Object instance, or an object that acts like one. 
@@ -100,8 +67,7 @@ I<object> is the CRUD object to be serialized. B<Required>
 
 =item
 
-I<rel_info> is a
-Rose::HTMLx::Form::Related::RelInfo object.
+I<rel_info> is the struct returned by Form->metadata->relationship_info() method.
 
 =item
 
@@ -110,8 +76,8 @@ B<Required>
 
 =item
 
-I<parent_object> is the originating object, in the case 
-where you are serializing related objects.
+I<parent_object> is the originating RDBO object, in the case where you are serializing
+related objects.
 
 =item
 
@@ -120,7 +86,7 @@ I<cat_context> is a $c object.
 =item
 
 I<show_related_values> is a hash ref of methods and foreign fields,
-as defined by Rose::HTMLx::Form::Related.
+as defined by B<I<TODO>>.
 
 =item
 
@@ -156,7 +122,7 @@ sub serialize_object {
     }
 
     my $flat = {};
-    if ( defined $opts{livegrid} and $opts{livegrid}->show_remove_button ) {
+    if ( defined $opts{datatable} and $opts{datatable}->show_remove_button ) {
         $flat->{'_remove'} = ' X ';
     }
 
@@ -166,23 +132,9 @@ sub serialize_object {
 
     for my $col (@$col_names) {
 
-        # if $col is array ref, then it is PK.
-        # however, value may not always be primary_key_uri_escaped()
-        # since the controller may define an alternate primary_key.
-        # so use the controller to get the value.
-        if ( ref($col) eq 'ARRAY' ) {
-            $flat->{ join( ';;', @$col ) } = $opts{livegrid}
-                ->controller->make_primary_key_string($object);
-            next;
-        }
-
-        # if $col has a . (dot) then it is a chained string of methods
-        my @methods = split( m/\./, $col );
-        my $first_method = shift @methods;
-
         # sanity check
-        if ( !$object->can($first_method) ) {
-            croak "no such method '$first_method' for object $object";
+        if ( !$object->can($col) ) {
+            croak "no such method '$col' for object $object";
         }
 
         # non-accessor methods. these are NOT FK methods.
@@ -213,47 +165,30 @@ sub serialize_object {
                 }
 
                 if ($obj_to_pass) {
-                    eval {
-                        $flat->{$col}
-                            = $object->$first_method( $opts{parent} );
-                    };
+                    eval { $flat->{$col} = $object->$col( $opts{parent} ); };
                     if ($@) {
                         $flat->{$col} = '[not available]';
                     }
                 }
                 else {
-                    $flat->{$col} = $object->$first_method;
+                    $flat->{$col} = $object->$col;
                 }
 
             }
             else {
-                eval {
-                    $flat->{$col} = $object->$first_method( $opts{parent} );
-                };
+                eval { $flat->{$col} = $object->$col( $opts{parent} ); };
                 if ($@) {
                     $flat->{$col} = '[not available]';
                 }
             }
 
-            next;
-
-        }
-
-        # get end value
-        my $value = $object->$first_method;
-        if ( defined $value ) {
-            for my $m (@methods) {
-                my $v = $value->$m;
-                if ( defined $v ) {
-                    $value = $v;
-                }
-            }
         }
 
         # DateTime objects
-        if ( blessed($value) && $value->isa('DateTime') ) {
-            if ( defined $value->epoch ) {
-                $flat->{$col} = $value->strftime( $self->datetime_format );
+        elsif ( blessed( $object->$col ) && $object->$col->isa('DateTime') ) {
+            if ( defined $object->$col->epoch ) {
+                $flat->{$col}
+                    = $object->$col->strftime( $self->datetime_format );
             }
             else {
                 $flat->{$col} = '';
@@ -273,92 +208,48 @@ sub serialize_object {
                 $flat->{$col} = $object->$method->$ff;
             }
             else {
-                $flat->{$col} = $value;
+                $flat->{$col} = $object->$col;
             }
         }
 
         # booleans
-        elsif ( $object->can('column_is_boolean')
-            and $object->column_is_boolean($col) )
+        # TODO DBIC et al.
+        elsif ( $object->isa('Rose::DB::Object')
+            and $object->meta->column($col)
+            and $object->meta->column($col)->type eq 'boolean' )
         {
-            $flat->{$col} = $value ? 'true' : 'false';
+            $flat->{$col} = $object->$col ? 'true' : 'false';
         }
 
         # default
         else {
-            $flat->{$col} = $value;
+            $flat->{$col} = $object->$col;
 
         }
 
     }
 
-    # if results were passed in, treat them as child list
-    if ( $opts{results} ) {
-        my @data;
-        my $relname = delete $opts{relname}
-            or croak "relname required if results defined";
-        my $relname_fields = delete $opts{relname_fields}
-            or croak "relname_fields required if results defined";
-        $flat->{$relname} = [];
-
-        #warn 'results=' . $opts{results};
-        if ( ref $opts{results} eq 'ARRAY' ) {
-            for my $r ( @{ $opts{results} } ) {
-                push @{ $flat->{$relname} },
-                    $self->serialize_object(
-                    object    => $r,
-                    col_names => $relname_fields,
-                    );
-            }
-        }
-        else {
-            while ( my $r = $opts{results}->next ) {
-                push @{ $flat->{$relname} },
-                    $self->serialize_object(
-                    object    => $r,
-                    col_names => $relname_fields,
-                    );
-            }
-        }
-    }
-
-    # html escape
-    if ( $self->html_escape ) {
-        for ( keys %$flat ) {
-            next if !defined $flat->{$_};
-            next if ref $flat->{$_};
-            $flat->{$_} =~ s/([$ToEscape])/$Ents{$1}/og;
-        }
-    }
-
     return $flat;
 
 }
 
-=head2 serialize_livegrid( I<livegrid_object> )
+=head2 serialize_datatable( I<datatable_object> )
 
 Returns array ref of hash refs as passed through serialize_object().
 
 =cut
 
-sub serialize_livegrid {
-    my $self     = shift;
-    my $livegrid = shift or croak "LiveGrid object required";
-    my $results  = $livegrid->results
-        or croak "no results in LiveGrid object";
-    my $method_name = $livegrid->method_name || '';
-    my $params = $livegrid->c->req->params;
-    my $max_loops;
-    if ( $results->query->{limit} ) {
-        $max_loops = 0;    # db handled the limit
-    }
-    else {
-        $max_loops
-            = $params->{'cxc-no_page'}
-            ? 0
-            : (    $params->{'cxc-page_size'}
-                || $livegrid->controller->page_size );
-    }
+sub serialize_datatable {
+    my $self      = shift;
+    my $datatable = shift or croak "DataTable object required";
+    my $results   = $datatable->results
+        or croak "no results in DataTable object";
+    my $method_name = $datatable->method_name || '';
+    my $max_loops
+        = $datatable->form->app->req->params->{_no_page}
+        ? 0
+        : (    $datatable->form->app->req->params->{_page_size}
+            || $datatable->controller->page_size );
 
     my $counter = 0;
     my @data;
@@ -380,22 +271,22 @@ sub serialize_livegrid {
         push(
             @data,
             $self->serialize_object(
-                {   object              => $object,
-                    method_name         => $method_name,
-                    col_names           => $livegrid->col_names,
-                    parent              => $livegrid->c->stash->{object},
-                    c                   => $livegrid->c,
-                    show_related_values => $livegrid->show_related_values,
+                {   object      => $object,
+                    method_name => $method_name,
+                    col_names   => $datatable->col_names,
+                    parent      => $datatable->form->app->stash->{object},
+                    c           => $datatable->form->app,
+                    show_related_values => $datatable->show_related_values,
                     takes_object_as_argument =>
-                        $livegrid->form->metadata->takes_object_as_argument,
-                    livegrid => $livegrid,
+                        $datatable->form->metadata->takes_object_as_argument,
+                    datatable => $datatable,
                 }
             )
         );
         last if $max_loops > 0 && ++$counter > $max_loops;
     }
 
-    $livegrid->{count} = $counter;
+    $datatable->{count} = $counter;
 
     return \@data;
 }
@@ -423,7 +314,7 @@ sponsored the development of this software.
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 by the Regents of the University of Minnesota.
-
+All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
