@@ -5,16 +5,13 @@ use strict;
 use Carp;
 use base qw( Catalyst::View::TT );
 use Data::Dump qw( dump );
-use MRO::Compat;
-use mro "c3";
+use Class::C3;
 use Path::Class;
 use Class::Inspector;
 use CatalystX::CRUD::YUI;
 use CatalystX::CRUD::YUI::TT;
-use Search::Tools::UTF8;
-use Encode;
 
-our $VERSION = '0.030_01';
+our $VERSION = '0.001';
 
 =head1 NAME
 
@@ -22,12 +19,11 @@ CatalystX::CRUD::YUI::View - base View class
 
 =head1 SYNOPSIS
 
- # see catalyst::View::TT
+ # TODO
 
 =head1 DESCRIPTION
 
-CatalystX::CRUD::YUI::View is a subclass of Catalyst::View::TT that
-extends the base class in a few minor ways. See METHODS for details.
+ # TODO
 
 =head1 CONFIGURATION
 
@@ -48,7 +44,6 @@ __PACKAGE__->config(
     TEMPLATE_EXTENSION => '.tt',
     PRE_PROCESS        => 'crud/tt_config.tt',
     WRAPPER            => 'crud/wrapper.tt',
-    ENCODING           => 'utf-8',
 );
 
 =head1 METHODS
@@ -94,7 +89,7 @@ sub new {
         }
         push( @inc_path, $path );
     }
-
+    
     #dump \@inc_path;
 
     $class->config( { INCLUDE_PATH => \@inc_path } );
@@ -155,60 +150,6 @@ sub template_vars {
         );
 }
 
-=head2 process
-
-Overrides base method to test if C<template> is set in stash,
-and if it is, tests that it exists before calling next::method().
-If it does not exist, will change the C<template> value in stash
-to be C<crud/I<file>.tt>> in order to call the default crud template.
-
-This path mangling allows you to avoid creating .tt files for all your actions
-unless you want to override the default template's behaviour.
-
-=cut
-
-sub process {
-    my ( $self, $c ) = @_;
-
-    my $template = $c->stash->{template}
-        || $c->action . $self->config->{TEMPLATE_EXTENSION};
-    unless ( defined $template ) {
-        $c->log->debug('No template specified for rendering') if $c->debug;
-        return 0;
-    }
-
-    # test for file existence
-    my $template_exists;
-    for my $base ( @{ $self->paths } ) {
-        my $file = Path::Class::file( $base, $template );
-        if ( -s $file ) {
-            $template_exists = 1;
-            last;
-        }
-    }
-    unless ($template_exists) {
-        my $file     = Path::Class::file($template);
-        my $basename = $file->basename;
-        $c->log->debug("using default template $basename") if $c->debug;
-        $c->stash( template => Path::Class::file( 'crud', $basename ) . '' );
-    }
-
-    return $self->next::method($c);
-
-}
-
-=head2 render
-
-Overrides base method to coerce output into UTF-8.
-
-=cut
-
-sub render {
-    my ($self, @arg) = @_; 
-    my $out = $self->next::method(@arg);
-    return encode_utf8( to_utf8( $out ) );
-}
-
 1;
 
 __END__
@@ -232,7 +173,7 @@ sponsored the development of this software.
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 by the Regents of the University of Minnesota.
-
+All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
